@@ -5,19 +5,22 @@ echo "" 												>> $EXTENSION/build_order.txt
 	
 # Required
 [[ $(command -v gdbus) == "" ]] && echo "Installing glib" && extension --install glib && echo "Finished glib"
-[ ! -f /lib/libsigc-3.0.so ] && echo "Installing libsigcpp:3.6.0" && extension --install libsigcpp:3.6.0 && echo "Finished libsigcpp:3.6.0"
+[ ! -f /lib/libsigc-2.0.so ] && echo "Installing libsigcpp2" && extension --install libsigcpp2 && echo "Finished libsigcpp2"
 # Optional
 if [[ $INSTALL_OPTIONAL != false ]]; then 
 	[[ $(command -v doxygen) == "" ]] && echo "Installing doxygen" && extension --install doxygen && echo "Finished doxygen"
-	#[ ! -f /lib/libgiognomeproxy.so ] && echo "Installing glib_networking" && extension --install glib_networking && echo "Finished glib_networking"
-	#[[ $(command -v certtool) == "" ]] && echo "Installing gnutls" && extension --install gnutls && echo "Finished gnutls"
 	[[ $(command -v xsltproc) == "" ]] && echo "Installing libxslt" && extension --install libxslt && echo "Finished libxslt"
 fi
+# Tests
+if [[ $INSTALL_TESTS != false ]]; then 
+	[ ! -f /lib/libgiognomeproxy.so ] && echo "Installing glib_networking" && extension --install glib_networking && echo "Finished glib_networking"
+	[[ $(command -v certtool) == "" ]] && echo "Installing gnutls" && extension --install gnutls && echo "Finished gnutls"
+fi
 
-if [ $BUILD_ALL == "false" ] && [ ! -f /lib/libgiomm-2.68.so ]; then
-	echo "glibmm" 										>> $EXTENSION/build_order.txt
+if [ $BUILD_ALL == "false" ] && [ ! -f /lib/libgiomm-2.4.so ]; then
+	echo "glibmm_24" 									>> $EXTENSION/build_order.txt
 fi
 if [ $BUILD_ALL == "true" ]; then
-	echo "glibmm" 										>> $EXTENSION/build_order.txt
+	echo "glibmm_24" 									>> $EXTENSION/build_order.txt
 fi
 echo "complete _" 										>> $EXTENSION/build_order.txt
